@@ -1,6 +1,6 @@
 # This is the PyQt5 build script.
 #
-# Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2021 Riverbank Computing Limited <info@riverbankcomputing.com>
 # 
 # This file is part of PyQt5.
 # 
@@ -33,8 +33,7 @@ class PyQt(PyQtProject):
     def __init__(self):
         """ Initialise the project. """
 
-        super().__init__(sip_module='PyQt5.sip', abi_version='12.8',
-                dunder_init=True, tag_prefix='Qt',
+        super().__init__(dunder_init=True, tag_prefix='Qt',
                 console_scripts=[
                     'pylupdate5 = PyQt5.pylupdate_main:main',
                     'pyrcc5 = PyQt5.pyrcc_main:main',
@@ -44,8 +43,8 @@ class PyQt(PyQtProject):
         self.bindings_factories = [Qt, QtCore, QtNetwork, QtGui, QtWidgets,
             QtQml, QAxContainer, QtAndroidExtras, QtBluetooth, QtDBus,
             QtDesigner, Enginio, QtHelp, QtMacExtras, QtMultimedia,
-            QtMultimediaWidgets, QtNetworkAuth, QtNfc, QtOpenGL, QtPositioning,
-            QtLocation, QtPrintSupport, QtQuick, QtQuick3D, QtQuickWidgets,
+            QtMultimediaWidgets, QtNfc, QtOpenGL, QtPositioning, QtLocation,
+            QtPrintSupport, QtQuick, QtQuick3D, QtQuickWidgets,
             QtRemoteObjects, QtSensors, QtSerialPort, QtSql, QtSvg, QtTest,
             QtTextToSpeech, QtWebChannel, QtWebKit, QtWebKitWidgets,
             QtWebSockets, QtWinExtras, QtX11Extras, QtXml, QtXmlPatterns,
@@ -84,7 +83,7 @@ def find_qt():
     if not os.path.isfile(dll_dir + qtcore_dll):
         path = os.environ['PATH']
 
-        dll_dir = os.path.dirname(__file__) + '\\\\Qt\\\\bin'
+        dll_dir = os.path.dirname(__file__) + '\\\\Qt5\\\\bin'
         if os.path.isfile(dll_dir + qtcore_dll):
             path = dll_dir + ';' + path
             os.environ['PATH'] = path
@@ -156,6 +155,12 @@ del find_qt
         if tool not in Option.BUILD_TOOLS:
             return
 
+        # Check we support the version of Qt.
+        if self.builder.qt_version >> 16 != 5:
+            raise UserException(
+                    "Qt v5 is required, not v{0}".format(
+                            self.builder.qt_version_str))
+
         # Automatically confirm the license if there might not be a command
         # line option to do so.
         if tool == 'pep517':
@@ -757,19 +762,6 @@ class QtNetwork(PyQtBindings):
         super().__init__(project, 'QtNetwork', qmake_QT=['network', '-gui'])
 
 
-class QtNetworkAuth(PyQtBindings):
-    """ The QtNetworkAuth bindings. """
-
-    def __init__(self, project):
-        """ Initialise the bindings. """
-
-        super().__init__(project, 'QtNetworkAuth',
-                qmake_CONFIG=['c++11'],
-                qmake_QT=['network', 'networkauth', '-gui'],
-                test_headers=['qtnetworkauthversion.h'],
-                test_statement='const char *v = QTNETWORKAUTH_VERSION_STR')
-
-
 class QtNfc(PyQtBindings):
     """ The QtNfc bindings. """
 
